@@ -1,5 +1,12 @@
 from airflow.exceptions import AirflowException
-from airflow.models.baseoperator import BaseOperator
+
+try:
+    # Airflow >= 2.3
+    from airflow.models.abstractoperator import AbstractOperator
+except ImportError:  # pragma: no cover
+    # Airflow < 2.3
+    from airflow.models.baseoperator import BaseOperator as AbstractOperator
+
 from airflow.models.xcom_arg import XComArg
 
 
@@ -12,7 +19,7 @@ class UpstreamTaskMixin:
         for task in upstream_tasks:
             if isinstance(task, XComArg):
                 self.set_upstream(task.operator)
-            elif isinstance(task, BaseOperator):
+            elif isinstance(task, AbstractOperator):
                 self.set_upstream(task)
             else:
                 raise AirflowException(
